@@ -1,16 +1,21 @@
 import ast
-from typing import List
+from typing import List, Optional
 
+from ..plugins.manager import PluginManager
 from .codegen import generate_import_from
 
 
 class InitFileGenerator:
-    def __init__(self) -> None:
+    def __init__(self, plugin_manager: Optional[PluginManager] = None) -> None:
         self.imports: list = []
+        self.plugin_manager = plugin_manager
 
     def add_import(self, names: List[str], from_: str, level: int = 0) -> None:
         """Add import to be included in init file."""
-        self.imports.append(generate_import_from(names=names, from_=from_, level=level))
+        import_ = generate_import_from(names=names, from_=from_, level=level)
+        if self.plugin_manager:
+            import_ = self.plugin_manager.generate_init_import(import_)
+        self.imports.append(import_)
 
     def generate(self) -> ast.Module:
         """Generate init with imports and public api of package."""
@@ -34,4 +39,6 @@ class InitFileGenerator:
                     lineno=len(self.imports) + 1,
                 )
             )
+        if self.plugin_manager:
+            module = self.plugin_manager.generate_init_module(module)
         return module
